@@ -15,9 +15,9 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # Test of basic assembly functionality.
-# Keep this in sync with sister tests asm2.test and asm3.test.
+# Keep this in sync with sister tests 'asm2.sh' and 'asm3.sh'.
 
-. ./defs || Exit 1
+. ./defs || exit 1
 
 mv configure.ac configure.stub
 
