@@ -17,9 +17,9 @@
 # TAP support:
 #  - non-directive comments in TAP results are kept verbatim
 
-. ./defs || Exit 1
+. ./defs || exit 1
 
-. "$am_testauxdir"/tap-setup.sh || fatal_ "sourcing tap-setup.sh"
+. tap-setup.sh
 
 cat > all.test <<END
 1..5
@@ -30,7 +30,7 @@ not ok #    TOD${tab}
 ok 5 # ${tab}${tab}TOOD${tab}${sp}${sp}
 END
 
-$MAKE check >stdout && { cat stdout; Exit 1; }
+$MAKE check >stdout && { cat stdout; exit 1; }
 cat stdout
 
 count_test_results total=5 pass=3 fail=2 xpass=0 xfail=0 skip=0 error=0
